fedex

Package fedex |
[hide private]
[frames] | no frames]

# Package fedex

source code

# python-fedex API Documentation

The python-fedex module is a light wrapper around Fedex's Web Services SOAP API. Using the excellent suds SOAP client, the Fedex requests and responses are trivial to work with.

## What python-fedex is

- A light wrapper around Fedex Web Services SOAP API.
- Simple and easy to use.
- Minimal by design.

## What python-fedex is not

- An abstraction layer. python-fedex only assembles the needed SOAP calls and returns a SOAP response through suds. This is easy enough to work with that no abstraction is needed. Doing so would limit your use of the data.
- Anything more than a light wrapper.

## A note on completeness

python-fedex was created for use with some of my internal projects. For the initial release, only the things that I needed at the time were implemented. If there is missing functionality, please report an issue so that I may make this module more useful to others. Likewise, feel free to submit patches as well if you would like to help.

## Getting Started

The best place to get started is by viewing the examples in the 'examples' directory. These should be very self-explanatory. For further details, you may review the API here, or get support by reading the instructions in the appropriately named section below.

The services module is also a good place to start looking at the different objects used for issuing Fedex requests.

As a general tip, the best way to see which attributes are available on WSDL objects is to simply print them, hitting their __str__() method.

## Fedex Documentation

If you are wondering what attributes or variables are present, you'll want to refer to the Fedex Web Services documentation at http://fedex.com/developer/. Complete specification documents are there, which correspond very closely with what you'll be able to do with python-fedex.

## Getting Support

If you have any questions, problems, ideas, or patch submissions, please visit our Google Code project and enter an issue in the Issue Tracker.

Submodules | [hide private]
fedex.base_service: The base_service module contains classes that form the low level foundations of the Web Service API. fedex.config: The config module contains the FedexConfig class, which is passed to the Fedex API calls. fedex.printers: Optional classes used for the convenient printing of FedEx labels from FedexProcessShipmentRequest objects. fedex.printers.unix: This module provides a label printing wrapper class for Unix-based installations. fedex.services: This module contains the wrappers around Fedex Web Service requests which you will want to instantiate and use with a FedexConfig object supplying your static details. fedex.services.address_validation_service: This package contains the shipping methods defined by Fedex's AddressValidationService WSDL file. fedex.services.package_movement: This package contains classes to check service availability, route, and postal codes. fedex.services.rate_service: This package contains classes to request pre-ship rating information and to determine estimated or courtesy billing quotes. fedex.services.ship_service: This package contains the shipping methods defined by Fedex's ShipService WSDL file. fedex.services.track_service: This package contains the shipment tracking methods defined by Fedex's TrackService WSDL file.

Variables | [hide private]
| VERSION = ``'``1.0.4``'``
| __package__ = `None`